<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Repositories\GpeEsocialRegistro;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1330 - Serviços Tomados de Cooperativa de Trabalho.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S1330
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1330, Serviços Tomados de
     * Cooperativa de Trabalho.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $idRetificacao           Identificador de Retificação dos arquivos ou não.
     * @param $nrRecibo                Número do Recibo do primeiro envio em caso de Retificação.
     * @param $idApuracao              Identificador da apuração Mensal ou Anual.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao)
    {
        $S1330 = GpeEsocialRegistro::dataSetEsocial_S1330(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao
        );

        // Loop para gerar os estabelecimentos tomadores referentes ao empregador acima
        foreach ($S1330 as &$row) {
            $estabs = GpeEsocialRegistro::s13xx_EstabPrestTomad('E', $row['NRESTRUTURAM'], $inicioPeriodo, $fimPeriodo, $nrorg);

            // Loop para gerar os prestadores referentes ao estabelecimento acima
            $contEstab = 1;
            $estabelecimento = null;
            foreach($estabs as &$estab) {
                $notas = GpeEsocialRegistro::s13xx_NfServPrestTomad('E', $estab['CDFILIRECE'], null, $inicioPeriodo, $fimPeriodo);

                // Loop para gerar os itens referentes à nota acima
                $contNF = 1;
                $nfTerceiros = null;
                foreach ($notas as &$notafiscal) {
                    $nfTerceiros[$contNF] =
                        array("_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS" => '1',
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_CNPJCOOPERATIVA" => $notafiscal['CNPJCOOPERATIVA'],
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_SERIE" => $notafiscal['SERIE'],
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_NUMDOCTO" => $notafiscal['NUMDOCTO'],
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_DTEMISSAONF" => $notafiscal['DTEMISSAONF'],
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_DTPAGTONF" => $notafiscal['DTPAGTONF'],
                            "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS_VLRBRUTO" => $notafiscal['VLRBRUTO']);
                    $contNF++;
                }

                $estabelecimento[$contEstab] =
                    array("_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO" => '1',
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TPINSCRICAO" => $estab['ESTABTPINSCRICAO'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NRINSCRICAO" => $estab['ESTABNRINSCRICAO'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_NFSTERCEIROS" => $nfTerceiros,
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TOTBASECOOP_INDINCIDENCIA" => $estab['INDINCIDENCIA'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TOTBASECOOP_VLRBASECOOP" => $estab['VLRBASECOOP'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TOTBASECOOP_VLRBASECOOP15" => $estab['VLRBASECOOP15'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TOTBASECOOP_VLRBASECOOP20" => $estab['VLRBASECOOP20'],
                        "_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO_TOTBASECOOP_VLRBASECOOP25" => $estab['VLRBASECOOP25']);
                $contEstab++;
            }

            $row['_EVTFPSERVTOMADOSCOOP_INFOSERVTOMADOS_IDEESTABELECIMENTO'][1] = $estabelecimento;
        }

        return $S1330;
    }

}